/*
 * articles.js: Client for Symphony Articles API
 *
 * (C) 2015 4LOOP Inc.
 */

var Client = require('./client').Client,
  util = require('util');

var Articles = exports.Articles = function(options) {
  Client.call(this, options);
};

util.inherits(Articles, Client);

Articles.prototype.viewall = function(params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  this.request('GET', ['articles'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, params, callback, function(res, result) {
    callback(null, result);
  });

};

Articles.prototype.create = function(params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (typeof params.title === 'undefined') {
    return callback(new Error('Symphony Error (title parameter required)'));
  }

  if (typeof params.description === 'undefined') {
    return callback(new Error('Symphony Error (description parameter required)'));
  }

  if (typeof params.article === 'undefined') {
    return callback(new Error('Symphony Error (article parameter required)'));
  }

  this.request('POST', ['articles'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    title: params.title,
    description: params.description,
    article: params.article,
    date_implemented: params.date_implemented
  }, callback, function(res, result) {
    callback(null, result);
  });

};

Articles.prototype.view = function(article_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!article_id) {
    return callback(new Error('Symphony Error (article_id parameter required)'));
  }
  this.request('GET', ['articles', article_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

Articles.prototype.update = function(article_id, params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (typeof params.title === 'undefined') {
    return callback(new Error('Symphony Error (title parameter required)'));
  }

  if (typeof params.description === 'undefined') {
    return callback(new Error('Symphony Error (description parameter required)'));
  }

  if (typeof params.article === 'undefined') {
    return callback(new Error('Symphony Error (article parameter required)'));
  }

  if (!article_id) {
    return callback(new Error('Symphony Error (article_id parameter required)'));
  }
  this.request('PUT', ['articles', article_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    title: params.title,
    description: params.description,
    article: params.article,
    date_implemented: params.date_implemented
  }, callback, function(res, result) {
    callback(null, result);
  });
};

Articles.prototype.delete = function(article_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!article_id) {
    return callback(new Error('Symphony Error (article_id parameter required)'));
  }
  this.request('DELETE', ['articles', article_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

Articles.prototype.on_publish = function(article_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!article_id) {
    return callback(new Error('Symphony Error (article_id parameter required)'));
  }
  this.request('PUT', ['articles', article_id, 'publish'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

Articles.prototype.on_unpublish = function(article_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!article_id) {
    return callback(new Error('Symphony Error (article_id parameter required)'));
  }
  this.request('PUT', ['articles', article_id, 'unpublish'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

Articles.prototype.view_tags = function(article_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!article_id) {
    return callback(new Error('Symphony Error (article_id parameter required)'));
  }
  this.request('GET', ['articles', article_id, 'tags'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

Articles.prototype.view_media = function(article_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!article_id) {
    return callback(new Error('Symphony Error (article_id parameter required)'));
  }
  this.request('GET', ['articles', article_id, 'media'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};
