/*
 * banks.js: Client for Symphony Banks API
 *
 * (C) 2015 4LOOP Inc.
 */

var Client = require('./client').Client,
  util = require('util');

var Banks = exports.Banks = function(options) {
  Client.call(this, options);
};

util.inherits(Banks, Client);


Banks.prototype.viewall = function(callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  this.request('GET', ['banks'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });

};


Banks.prototype.create = function(params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (typeof params.name === 'undefined') {
    return callback(new Error('Symphony Error (name parameter required)'));
  }

  if (typeof params.address === 'undefined') {
    return callback(new Error('Symphony Error (address parameter required)'));
  }

  this.request('POST', ['banks'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    name: params.name,
    address: params.address
  }, callback, function(res, result) {
    callback(null, result);
  });

};


Banks.prototype.view = function(bank_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (typeof params.name === 'undefined') {
    return callback(new Error('Symphony Error (name parameter required)'));
  }

  if (typeof params.address === 'undefined') {
    return callback(new Error('Symphony Error (address parameter required)'));
  }

  if (!bank_id) {
    return callback(new Error('Symphony Error (bank_id parameter required)'));
  }
  this.request('GET', ['banks', bank_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

Banks.prototype.update = function(bank_id, params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!bank_id) {
    return callback(new Error('Symphony Error (bank_id parameter required)'));
  }
  this.request('PUT', ['banks', bank_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    name: params.name,
    address: params.address
  }, callback, function(res, result) {
    callback(null, result);
  });
};

Banks.prototype.delete = function(bank_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!bank_id) {
    return callback(new Error('Symphony Error (bank_id parameter required)'));
  }
  this.request('DELETE', ['banks', bank_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

Banks.prototype.view_tags = function(bank_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!bank_id) {
    return callback(new Error('Symphony Error (bank_id parameter required)'));
  }
  this.request('GET', ['banks', bank_id, 'tags'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};
