/*
 * bundle.js: Client for Symphony's Product Bundle API
 *
 * (C) 2017 4LOOP Inc.
 */

var Client = require('./client').Client,
    util = require('util');

var Bundle = exports.Bundle = function(options) {
    Client.call(this, options);
};

util.inherits(Bundle, Client);


Bundle.prototype.viewall = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    this.request('GET', ['product-bundle'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, params, callback, function(res, result) {
        callback(null, result);
    });
};

Bundle.prototype.create = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.bundle_name === 'undefined') {
        return callback(new Error('Symphony Error (bundle_name parameter required)'));
    }

    if (typeof params.bundle_description === 'undefined') {
        return callback(new Error('Symphony Error (bundle_description parameter required)'));
    }

    if (typeof params.bundle_code === 'undefined') {
        return callback(new Error('Symphony Error (bundle_code parameter required)'));
    }

    if (typeof params.product_type_id === 'undefined') {
        return callback(new Error('Symphony Error (product_type_id parameter required)'));
    }

    if (typeof params.bundle_brand === 'undefined') {
        return callback(new Error('Symphony Error (bundle_brand parameter required)'));
    }


    this.request('POST', ['product-bundle'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        bundle_name: params.bundle_name,
        bundle_description: params.bundle_description,
        bundle_overview: params.bundle_overview,
        sell_price: params.sell_price,
        product_type_id: params.product_type_id,
        bundle_code: params.bundle_code,
        bundle_brand: params.bundle_brand,
        start_date: params.start_date,
        end_date: params.end_date,
        is_published: params.is_published,
        is_archived: params.is_archived,
        barcode: params.barcode
    }, callback, function(res, result) {
        callback(null, result);
    });
};


Bundle.prototype.view = function(bundle_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }
    this.request('GET', ['product-bundle', bundle_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Bundle.prototype.update = function(bundle_id, params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.item_name === 'undefined') {
        return callback(new Error('Symphony Error (item_name parameter required)'));
    }

    if (typeof params.ptype_id === 'undefined') {
        return callback(new Error('Symphony Error (ptype_id parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }

    this.request('PUT', ['product-bundle', bundle_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
      bundle_name: params.bundle_name,
      bundle_description: params.bundle_description,
      bundle_overview: params.bundle_overview,
      sell_price: params.sell_price,
      product_type_id: params.product_type_id,
      bundle_code: params.bundle_code,
      bundle_brand: params.bundle_brand,
      start_date: params.start_date,
      end_date: params.end_date,
      is_published: params.is_published,
      is_archived: params.is_archived,
      barcode: params.barcode
    }, callback, function(res, result) {
        callback(null, result);
    });
};

Bundle.prototype.delete = function(bundle_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }
    this.request('DELETE', ['product-bundle', bundle_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Bundle.prototype.on_archive = function(bundle_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }
    this.request('PUT', ['product-bundle', bundle_id,'archive'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Bundle.prototype.on_publish = function(bundle_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }
    this.request('PUT', ['product-bundle', bundle_id,'publish'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Bundle.prototype.on_draft = function(bundle_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }
    this.request('PUT', ['product-bundle', bundle_id,'draft'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Bundle.prototype.view_attributes = function(bundle_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }
    this.request('GET',['product-bundle', bundle_id,'attributes'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Bundle.prototype.view_category = function(bundle_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }
    this.request('GET', ['product-bundle', bundle_id,'category'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Bundle.prototype.view_tags = function(bundle_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }
    this.request('GET', ['product-bundle', bundle_id,'tags'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Bundle.prototype.view_related = function(bundle_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!bundle_id) {
        return callback(new Error('Symphony Error (bundle_id parameter required)'));
    }
    this.request('GET', ['product-bundle', bundle_id,'related'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};
