/*
 * cardtype.js: Client for Symphony Card Type API
 *
 * (C) 2015 4LOOP Inc.
 */

var Client = require('./client').Client,
  util = require('util');

var CardType = exports.CardType = function(options) {
  Client.call(this, options);
};

util.inherits(CardType, Client);


CardType.prototype.viewall = function(callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  this.request('GET', ['cardtype'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });

};


CardType.prototype.create = function(params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (typeof params.name === 'undefined') {
    return callback(new Error('Symphony Error (name parameter required)'));
  }

  this.request('POST', ['cardtype'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    name: params.name
  }, callback, function(res, result) {
    callback(null, result);
  });

};


CardType.prototype.view = function(type_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!type_id) {
    return callback(new Error('Symphony Error (type_id parameter required)'));
  }
  this.request('GET', ['cardtype', type_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

CardType.prototype.update = function(type_id, params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (typeof params.name === 'undefined') {
    return callback(new Error('Symphony Error (name parameter required)'));
  }

  if (!type_id) {
    return callback(new Error('Symphony Error (type_id parameter required)'));
  }
  this.request('PUT', ['cardtype', type_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    name: params.name
  }, callback, function(res, result) {
    callback(null, result);
  });
};

CardType.prototype.delete = function(type_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!type_id) {
    return callback(new Error('Symphony Error (type_id parameter required)'));
  }
  this.request('DELETE', ['cardtype', type_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};
