/*
 * categories.js: Client for Symphony Categories API
 *
 * (C) 2015 4LOOP Inc.
 */

var Client = require('./client').Client,
    util = require('util');

var Categories = exports.Categories = function(options) {
    Client.call(this, options);
};

util.inherits(Categories, Client);


Categories.prototype.viewall = function(params,callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    this.request('GET', ['categories'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey,params, callback, function(res, result) {
        callback(null, result);
    });

};


Categories.prototype.create = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.name === 'undefined') {
        return callback(new Error('Symphony Error (name parameter required)'));
    }

    if (typeof params.label === 'undefined') {
        return callback(new Error('Symphony Error (label parameter required)'));
    }

    this.request('POST', ['categories'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        name: params.name,
        label: params.label,
        description: params.description,
        parent_id: params.parent_id,
        is_visible: params.is_visible
    }, callback, function(res, result) {
        callback(null, result);
    });

};


Categories.prototype.view = function(c_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!c_id) {
        return callback(new Error('Symphony Error (c_id parameter required)'));
    }
    this.request('GET', ['categories', c_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Categories.prototype.update = function(c_id, params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }


    if (typeof params.name === 'undefined') {
        return callback(new Error('Symphony Error (name parameter required)'));
    }

    if (typeof params.label === 'undefined') {
        return callback(new Error('Symphony Error (label parameter required)'));
    }

    
    if (!c_id) {
        return callback(new Error('Symphony Error (c_id parameter required)'));
    }
    this.request('PUT', ['categories', c_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        name: params.name,
        label: params.label,
        description: params.description,
        parent_id: params.parent_id,
        is_visible: params.is_visible
    }, callback, function(res, result) {
        callback(null, result);
    });
};

Categories.prototype.delete = function(c_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!c_id) {
        return callback(new Error('Symphony Error (c_id parameter required)'));
    }
    this.request('DELETE', ['categories', c_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Categories.prototype.view_childs = function(c_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!c_id) {
        return callback(new Error('Symphony Error (c_id parameter required)'));
    }
    this.request('GET', ['categories', c_id, 'child'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Categories.prototype.on_publish = function(c_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!c_id) {
        return callback(new Error('Symphony Error (c_id parameter required)'));
    }
    this.request('PUT', ['categories', c_id, 'publish'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Categories.prototype.on_unpublish = function(c_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!c_id) {
        return callback(new Error('Symphony Error (c_id parameter required)'));
    }
    this.request('PUT', ['categories', c_id, 'unpublish'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Categories.prototype.view_tags = function(c_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!c_id) {
        return callback(new Error('Symphony Error (c_id parameter required)'));
    }
    this.request('GET', ['categories', c_id, 'tags'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};
