/*
 * client.js
 *
 * (C) 2017 4LOOP Inc.
 */

var fs = require('fs'),
    request = require('request');

var failCodes = {
    400: 'Bad Request',
    401: 'Not Authorized',
    403: 'Forbidden',
    404: 'Item Not Found',
    405: 'Method Not Allowed',
    409: 'Conflict',
    429: 'Too many API requests',
    500: 'Internal Server Error'
}; // failCodes

var apiVersion = '/api/v1';

var defaultOptions = {
    remoteUri: 'http://localhost:3001' + apiVersion
};

var serializeObj = function(obj) {
  var str = [];
  for(var p in obj)
    if (obj.hasOwnProperty(p)) {
      str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]));
    }
  return str.join("&");
}


var Client = exports.Client = function(options) {
    this.options = options || defaultOptions;
    if (!this.options.remoteUri) {
        this.options.remoteUri = defaultOptions.remoteUri;
    }
    this._request = request;

    if (typeof this.options.get !== 'function') {
        this.options.get = function(key) {
            return this[key];
        } // this.options.get
    } // if ( typeof this.options.get !== 'function' )
}; // Client


Client.prototype.request = function(method, uri, accessCode, accessKey, authKey) {
    var args = Array.prototype.slice.call(arguments),
        success = args.pop(),
        callback = args.pop(),
        body = typeof args[args.length - 1] === 'object' && !Array.isArray(args[args.length - 1]) && args.pop(),
        proxy = this.options.get('proxy');

    var options = {
        method: method || 'GET',
        uri: this.options.get('remoteUri') + '/' + uri.join('/'),
        headers: {
            'Content-Type': 'application/json'
        }
    }; // options

    if (authKey) {
        options.headers['Authorization'] = 'Bearer ' + authKey;
        options.headers['accesscode'] = accessCode;
        options.headers['accesskey'] = accessKey;
        //options.uri = options.uri + '?access_token=' + authKey
    }

    if(method !== 'GET'){
        if(body){
            options.body = JSON.stringify(body);
        }
    }else{
        if(body){
            options.uri = options.uri + '?' + serializeObj(body);
        }else{
            options.body = '{}';
        }
    }

    if (proxy) {
        options.proxy = proxy;
    }

    this._request(options, function(error, response, body) {
        // pretty format for connection refused error
        if (error && error.errno === 'ECONNREFUSED') {
            error.message = 'Unable to connect to ' + options.uri.magenta;
            error.message += ' (Connection Refused)'.red;
            delete error.stack;
        }

        if (error) {
            return callback && callback(error); // done
        }

        var statusCode, result, err;

        try {
            statusCode = response.statusCode.toString();
            result = JSON.parse(body);
        } catch (ex) {
            // ignore errors
        }

        if (Object.keys(failCodes).indexOf(statusCode) !== -1) {
            err = new Error('Symphony Error (' + statusCode + '): ' + failCodes[statusCode]);
            err.statusCode = statusCode;
            err.result = result;
            return callback && callback(err); // done
        } // if ( Object.keys( failCodes ).indexOf( statusCode ) !== -1 )

        success(response, result);
    }); // this._request
}; // request
