/*
 * companyinfo.js: Client for Symphony Company Information API
 *
 * (C) 2015 4LOOP Inc.
 */

var Client = require('./client').Client,
  util = require('util');

var CompanyInfo = exports.CompanyInfo = function(options) {
  Client.call(this, options);
};

util.inherits(CompanyInfo, Client);


CompanyInfo.prototype.viewall = function(params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  this.request('GET', ['companyinfo'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, params, callback, function(res, result) {
    callback(null, result);
  });

};


CompanyInfo.prototype.create = function(params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (typeof params.name === 'undefined') {
    return callback(new Error('Symphony Error (name parameter required)'));
  }

  if (typeof params.email_address === 'undefined') {
    return callback(new Error('Symphony Error (email_address parameter required)'));
  }

  if (typeof params.contact_number === 'undefined') {
    return callback(new Error('Symphony Error (contact_number parameter required)'));
  }

  this.request('POST', ['companyinfo'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    name: params.name,
    address: params.address,
    contact_number: params.contact_number,
    ABN: params.ABN,
    email_address: params.email_address,
    city: params.city,
    state: params.state,
    zipcode: params.zipcode,
    country: params.country,
    parent_id: params.parent_id,
    bill_name: params.bill_name,
    bill_address: params.bill_address,
    bill_city: params.bill_city,
    bill_state: params.bill_state,
    bill_zipcode: params.bill_zipcode,
    bill_country: params.bill_country,
    ship_name: params.ship_name,
    ship_address: params.ship_address,
    ship_city: params.ship_city,
    ship_state: params.ship_state,
    ship_zipcode: params.ship_zipcode,
    ship_country: params.ship_country
  }, callback, function(res, result) {
    callback(null, result);
  });

};


CompanyInfo.prototype.view = function(company_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!company_id) {
    return callback(new Error('Symphony Error (company_id parameter required)'));
  }
  this.request('GET', ['companyinfo', company_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

CompanyInfo.prototype.update = function(company_id, params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }


  if (typeof params.name === 'undefined') {
    return callback(new Error('Symphony Error (name parameter required)'));
  }

  if (typeof params.email_address === 'undefined') {
    return callback(new Error('Symphony Error (email_address parameter required)'));
  }

  if (typeof params.contact_number === 'undefined') {
    return callback(new Error('Symphony Error (contact_number parameter required)'));
  }


  if (!company_id) {
    return callback(new Error('Symphony Error (company_id parameter required)'));
  }
  this.request('PUT', ['companyinfo', company_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    name: params.name,
    address: params.address,
    contact_number: params.contact_number,
    ABN: params.ABN,
    email_address: params.email_address,
    city: params.city,
    state: params.state,
    zipcode: params.zipcode,
    country: params.country,
    parent_id: params.parent_id,
    bill_name: params.bill_name,
    bill_address: params.bill_address,
    bill_city: params.bill_city,
    bill_state: params.bill_state,
    bill_zipcode: params.bill_zipcode,
    bill_country: params.bill_country,
    ship_name: params.ship_name,
    ship_address: params.ship_address,
    ship_city: params.ship_city,
    ship_state: params.ship_state,
    ship_zipcode: params.ship_zipcode,
    ship_country: params.ship_country
  }, callback, function(res, result) {
    callback(null, result);
  });
};

CompanyInfo.prototype.delete = function(company_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!company_id) {
    return callback(new Error('Symphony Error (company_id parameter required)'));
  }
  this.request('DELETE', ['companyinfo', company_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

CompanyInfo.prototype.view_group = function(company_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!company_id) {
    return callback(new Error('Symphony Error (company_id parameter required)'));
  }
  this.request('GET', ['companyinfo', company_id, 'group'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};
