/*
 * customergroup.js: Client for Symphony Customer Group API
 *
 * (C) 2017 4LOOP Inc.
 */

var Client = require('./client').Client,
    util = require('util');

var CustomerGroup = exports.CustomerGroup = function (options) {
    Client.call(this, options);
}; // Apps

util.inherits(CustomerGroup, Client);


CustomerGroup.prototype.viewall = function (callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    }else if(!this.options.accessCode){
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    }else if(!this.options.accessKey){
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    this.request('GET', ['customergroup'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function (res, result) {
        callback(null, result);
    });
};

CustomerGroup.prototype.view = function(cg_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!cg_id) {
        return callback(new Error('Symphony Error (cg_id parameter required)'));
    }

    this.request('GET', ['customergroup', cg_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

CustomerGroup.prototype.create = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.name === 'undefined') {
        return callback(new Error('Symphony Error (name parameter required)'));
    }

    this.request('POST', ['customergroup'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        name: params.name,
        description: params.description,
        store_id: params.store_id
    }, callback, function(res, result) {
        callback(null, result);
    });
};


CustomerGroup.prototype.update = function(cg_id, params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!cg_id) {
        return callback(new Error('Symphony Error (cg_id parameter required)'));
    }

    this.request('PUT', ['customergroup', cg_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
      name: params.name,
      description: params.description,
      store_id: params.store_id
    }, callback, function(res, result) {
        callback(null, result);
    });
};


CustomerGroup.prototype.delete = function(cg_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!cg_id) {
        return callback(new Error('Symphony Error (cg_id, parameter required)'));
    }

    this.request('DELETE', ['customergroup', cg_id,], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

CustomerGroup.prototype.on_mappings = function(cg_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!cg_id) {
        return callback(new Error('Symphony Error (cg_id parameter required)'));
    }

    this.request('GET', ['customergroup', cg_id,'mapping'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

CustomerGroup.prototype.on_mapping = function(cg_id,_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!cg_id) {
        return callback(new Error('Symphony Error (cg_id parameter required)'));
    }

    this.request('GET', ['customergroup', cg_id,'mapping',_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};
