/*
 * paytype.js: Client for Symphony Pay Type API
 *
 * (C) 2015 4LOOP Inc.
 */

var Client = require('./client').Client,
  util = require('util');

var PayType = exports.PayType = function(options) {
  Client.call(this, options);
};

util.inherits(PayType, Client);


PayType.prototype.viewall = function(callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  this.request('GET', ['paytype'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });

};


PayType.prototype.create = function(params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (typeof params.name === 'undefined') {
    return callback(new Error('Symphony Error (name parameter required)'));
  }

  if (typeof params.description === 'undefined') {
    return callback(new Error('Symphony Error (description parameter required)'));
  }

  this.request('POST', ['paytype'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    name: params.name,
    description: params.description
  }, callback, function(res, result) {
    callback(null, result);
  });

};


PayType.prototype.view = function(type_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!type_id) {
    return callback(new Error('Symphony Error (type_id parameter required)'));
  }
  this.request('GET', ['paytype', type_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};

PayType.prototype.update = function(type_id, params, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!type_id) {
    return callback(new Error('Symphony Error (type_id parameter required)'));
  }
  this.request('PUT', ['paytype', type_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
    name: params.name,
    description: params.description
  }, callback, function(res, result) {
    callback(null, result);
  });
};

PayType.prototype.delete = function(type_id, callback) {
  if (!this.options.userAuthKey) {
    return callback(new Error('Symphony Error (userAuthKey parameter required)'));
  } else if (!this.options.accessCode) {
    return callback(new Error('Symphony Error (accessCode parameter required)'));
  } else if (!this.options.accessKey) {
    return callback(new Error('Symphony Error (accessKey parameter required)'));
  }

  if (!type_id) {
    return callback(new Error('Symphony Error (type_id parameter required)'));
  }
  this.request('DELETE', ['paytype', type_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
    callback(null, result);
  });
};
