/*
 * Persons.js: Client for Symphony Persons API
 *
 * (C) 2017 4LOOP Inc.
 */

var Client = require('./client').Client,
    util = require('util');

var Persons = exports.Persons = function(options) {
    Client.call(this, options);
};

util.inherits(Persons, Client);

Persons.prototype.viewall = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    this.request('GET', ['persons'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, params, callback, function(res, result) {
        callback(null, result);
    });
};


Persons.prototype.view = function(person_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!person_id) {
        return callback(new Error('Symphony Error (person_id parameter required)'));
    }

    this.request('GET', ['persons', person_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Persons.prototype.create = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.lastname === 'undefined') {
        return callback(new Error('Symphony Error (lastname parameter required)'));
    }

    if (typeof params.firstname === 'undefined') {
        return callback(new Error('Symphony Error (firstname parameter required)'));
    }

    if (typeof params.per_type_id === 'undefined') {
        return callback(new Error('Symphony Error (per_type_id parameter required)'));
    }

    this.request('POST', ['persons'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        lastname: params.lastname,
        firstname: params.firstname,
        middlename: params.middlename,
        per_type_id: params.per_type_id,
        gender: params.gender,
        birthdate: params.birthdate,
        email: params.email,
        mobile: params.mobile,
        company_name: params.company_name,
        address: params.address,
        address2: params.address2,
        city: params.city,
        state: params.state,
        zipcode: params.zipcode,
        country: params.country,
        timeZone: params.timeZone,
        store_id: params.store_id,
        date_end: params.date_end,
        date_start: params.date_start,
        company_username: params.company_username
    }, callback, function(res, result) {
        callback(null, result);
    });
};


Persons.prototype.update = function(person_id, params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!person_id) {
        return callback(new Error('Symphony Error (person_id parameter required)'));
    }

    this.request('PUT', ['persons', person_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        lastname: params.lastname,
        firstname: params.firstname,
        middlename: params.middlename,
        per_type_id: params.per_type_id,
        gender: params.gender,
        birthdate: params.birthdate,
        email: params.email,
        mobile: params.mobile,
        company_name: params.company_name,
        address: params.address,
        address2: params.address2,
        city: params.city,
        state: params.state,
        zipcode: params.zipcode,
        country: params.country,
        timeZone: params.timeZone,
        store_id: params.store_id,
        date_end: params.date_end,
        date_start: params.date_start,
        company_username: params.company_username
    }, callback, function(res, result) {
        callback(null, result);
    });
};


Persons.prototype.delete = function(person_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!person_id) {
        return callback(new Error('Symphony Error (person_id parameter required)'));
    }

    this.request('DELETE', ['persons', person_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

/*Persons.prototype.on_upload_image = function(person_id, params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!person_id) {
        return callback(new Error('Symphony Error (person_id parameter required)'));
    }

    this.request('POST', ['persons', person_id, 'upload-image'], undefined, params, callback, function(res, result) {
        callback(null, result);
    });
};*/

Persons.prototype.view_store = function(person_id,callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!person_id) {
        return callback(new Error('Symphony Error (person_id parameter required)'));
    }

    this.request('GET', ['persons', person_id, 'store'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};
