/*
 * product.js: Client for Symphony's Product API
 *
 * (C) 2017 4LOOP Inc.
 */

var Client = require('./client').Client,
    util = require('util');

var Product = exports.Product = function(options) {
    Client.call(this, options);
};

util.inherits(Product, Client);


Product.prototype.viewall = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    this.request('GET', ['product'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, params, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.create = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.item_name === 'undefined') {
        return callback(new Error('Symphony Error (item_name parameter required)'));
    }

    if (typeof params.ptype_id === 'undefined') {
        return callback(new Error('Symphony Error (ptype_id parameter required)'));
    }

    this.request('POST', ['product'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        item_name: params.item_name,
        sell_price: params.sell_price,
        vat: params.vat,
        ptype_id: params.ptype_id,
        product_code: params.product_code,
        brand: params.brand,
        start_date: params.start_date,
        end_date: params.end_date,
        is_published: params.is_published,
        is_archived: params.is_archived,
        item_overview: params.item_overview,
        item_description: params.item_description,
        barcode: params.barcode,
        purchase_price: params.purchase_price,
        markup: params.markup
    }, callback, function(res, result) {
        callback(null, result);
    });
};


Product.prototype.view = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('GET', ['product', product_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Product.prototype.update = function(product_id, params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.item_name === 'undefined') {
        return callback(new Error('Symphony Error (item_name parameter required)'));
    }

    if (typeof params.ptype_id === 'undefined') {
        return callback(new Error('Symphony Error (ptype_id parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }

    this.request('PUT', ['product', product_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        item_name: params.item_name,
        sell_price: params.sell_price,
        vat: params.vat,
        ptype_id: params.ptype_id,
        product_code: params.product_code,
        brand: params.brand,
        start_date: params.start_date,
        end_date: params.end_date,
        is_published: params.is_published,
        is_archived: params.is_archived,
        item_overview: params.item_overview,
        item_description: params.item_description,
        barcode: params.barcode,
        purchase_price: params.purchase_price,
        markup: params.markup
    }, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.delete = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('DELETE', ['product', product_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.on_archive = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('PUT', ['product', product_id,'archive'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.on_publish = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('PUT', ['product', product_id,'publish'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.on_draft = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('PUT', ['product', product_id,'draft'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.view_attributes = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('GET',['product', product_id,'attributes'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.view_category = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('GET', ['product', product_id,'category'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.view_stores = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('GET', ['product', product_id,'stores'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.view_tags = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('GET', ['product', product_id,'tags'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Product.prototype.view_related_products = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('GET', ['product', product_id,'related'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.view_related_product = function(product_id,rel_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }

    if(!rel_id){
        return callback(new Error('Symphony Error (rel_id parameter required)'));
    }
    this.request('GET', ['product', product_id,'related',rel_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Product.prototype.view_images = function(product_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!product_id) {
        return callback(new Error('Symphony Error (product_id parameter required)'));
    }
    this.request('GET', ['product', product_id,'images'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};
