/*
 * productype.js: Country for Symphony Product Type API
 *
 * (C) 2017 4LOOP Inc.
 */

var Client = require('./client').Client,
    util = require('util');

var ProductType = exports.ProductType = function(options) {
    Client.call(this, options);
}; // Apps

util.inherits(ProductType, Client);


ProductType.prototype.viewall = function(callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    this.request('GET', ['producttype'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

ProductType.prototype.create = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.name === 'undefined') {
        return callback(new Error('Symphony Error (name parameter required)'));
    }

    if (typeof params.label === 'undefined') {
        return callback(new Error('Symphony Error (label parameter required)'));
    }

    this.request('POST', ['producttype'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        name: params.name,
        label: params.label,
        description: params.description
    }, callback, function(res, result) {
        callback(null, result);
    });
};

ProductType.prototype.view = function(ptype_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!ptype_id) {
        return callback(new Error('Symphony Error (ptype_id parameter required)'));
    }

    this.request('GET', ['producttype', ptype_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

ProductType.prototype.update = function(ptype_id, params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!ptype_id) {
        return callback(new Error('Symphony Error (ptype_id parameter required)'));
    }

    if (typeof params.name === 'undefined') {
        return callback(new Error('Symphony Error (name parameter required)'));
    }

    if (typeof params.label === 'undefined') {
        return callback(new Error('Symphony Error (label parameter required)'));
    }

    this.request('PUT', ['producttype', ptype_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        name: params.name,
        label: params.label,
        description: params.description
    }, callback, function(res, result) {
        callback(null, result);
    });
};


ProductType.prototype.delete = function(ptype_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!ptype_id) {
        return callback(new Error('Symphony Error (ptype_id parameter required)'));
    }

    this.request('DELETE', ['producttype', ptype_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


ProductType.prototype.view_tags = function(ptype_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!ptype_id) {
        return callback(new Error('Symphony Error (ptype_id parameter required)'));
    }

    this.request('GET', ['producttype', ptype_id,'tags'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};
