/*
 * stores.js: Client for Symphony Store API
 *
 * (C) 2015 4LOOP Inc.
 */

var Client = require('./client').Client,
    util = require('util');

var Stores = exports.Stores = function(options) {
    Client.call(this, options);
};

util.inherits(Stores, Client);


Stores.prototype.viewall = function(callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    this.request('GET', ['store'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });

};


Stores.prototype.create = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.name === 'undefined') {
        return callback(new Error('Symphony Error (name parameter required)'));
    }

    if (typeof params.address === 'undefined') {
        return callback(new Error('Symphony Error (address parameter required)'));
    }

    if (typeof params.state === 'undefined') {
        return callback(new Error('Symphony Error (state parameter required)'));
    }

    if (typeof params.city === 'undefined') {
        return callback(new Error('Symphony Error (city parameter required)'));
    }

    if (typeof params.zipcode === 'undefined') {
        return callback(new Error('Symphony Error (zipcode parameter required)'));
    }

    if (typeof params.country === 'undefined') {
        return callback(new Error('Symphony Error (country parameter required)'));
    }

    if (typeof params.tin === 'undefined') {
        return callback(new Error('Symphony Error (tin parameter required)'));
    }

    if (typeof params.owner_name === 'undefined') {
        return callback(new Error('Symphony Error (owner_name parameter required)'));
    }

    if (typeof params.owner_email === 'undefined') {
        return callback(new Error('Symphony Error (owner_email parameter required)'));
    }

    if (typeof params.owner_contact_num === 'undefined') {
        return callback(new Error('Symphony Error (owner_contact_num parameter required)'));
    }

    if (typeof params.telno === 'undefined') {
        return callback(new Error('Symphony Error (telno parameter required)'));
    }

    if (typeof params.email_address === 'undefined') {
        return callback(new Error('Symphony Error (email_address parameter required)'));
    }

    this.request('POST', ['store'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        name: params.name,
        address: params.address,
        state: params.state,
        city: params.city,
        zipcode: params.zipcode,
        country: params.country,
        tin: params.tin,
        owner_name: params.owner_name,
        owner_email: params.owner_email,
        owner_contact_number: params.owner_contact_number,
        telno: params.telno,
        email_address: params.email_address,
        website: params.website,
        isVat: params.isVat,
        storetype_id: params.storetype_id,
        geo_latitude: params.geo_latitude,
        geo_longitude: params.geo_longitude,
        description: params.description
    }, callback, function(res, result) {
        callback(null, result);
    });

};


Stores.prototype.view = function(store_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!store_id) {
        return callback(new Error('Symphony Error (store_id parameter required)'));
    }
    this.request('GET', ['store', store_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Stores.prototype.update = function(store_id, params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!store_id) {
        return callback(new Error('Symphony Error (store_id parameter required)'));
    }
    this.request('PUT', ['store', store_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        name: params.name,
        address: params.address,
        state: params.state,
        city: params.city,
        zipcode: params.zipcode,
        country: params.country,
        tin: params.tin,
        owner_name: params.owner_name,
        owner_email: params.owner_email,
        owner_contact_number: params.owner_contact_number,
        telno: params.telno,
        email_address: params.email_address,
        website: params.website,
        isVat: params.isVat,
        storetype_id: params.storetype_id,
        geo_latitude: params.geo_latitude,
        geo_longitude: params.geo_longitude,
        description: params.description
    }, callback, function(res, result) {
        callback(null, result);
    });
};

Stores.prototype.delete = function(store_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!store_id) {
        return callback(new Error('Symphony Error (store_id parameter required)'));
    }
    this.request('DELETE', ['store', store_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Stores.prototype.view_products = function(store_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!store_id) {
        return callback(new Error('Symphony Error (store_id parameter required)'));
    }
    this.request('GET', ['store', store_id,'products'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Stores.prototype.view_tags = function(store_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!store_id) {
        return callback(new Error('Symphony Error (store_id parameter required)'));
    }
    this.request('GET', ['store', store_id,'tags'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Stores.prototype.view_media = function(store_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!store_id) {
        return callback(new Error('Symphony Error (store_id parameter required)'));
    }
    this.request('GET', ['store', store_id,'media'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};
