/*
 * supplier.js: Client for Symphony Supplier API
 *
 * (C) 2015 4LOOP Inc.
 */

var Client = require('./client').Client,
    util = require('util');

var Supplier = exports.Supplier = function(options) {
    Client.call(this, options);
};

util.inherits(Supplier, Client);


Supplier.prototype.viewall = function(callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    this.request('GET', ['supplier'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });

};


Supplier.prototype.create = function(params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (typeof params.name === 'undefined') {
        return callback(new Error('Symphony Error (name parameter required)'));
    }

    if (typeof params.address === 'undefined') {
        return callback(new Error('Symphony Error (address parameter required)'));
    }

    if (typeof params.contact_person === 'undefined') {
        return callback(new Error('Symphony Error (contact_person parameter required)'));
    }

    if (typeof params.contact_number === 'undefined') {
        return callback(new Error('Symphony Error (contact_number parameter required)'));
    }

    this.request('POST', ['supplier'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        name: params.name,
        address: params.address,
        contact_person: params.contact_person,
        contact_number: params.contact_number
    }, callback, function(res, result) {
        callback(null, result);
    });

};


Supplier.prototype.view = function(supplier_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!supplier_id) {
        return callback(new Error('Symphony Error (supplier_id parameter required)'));
    }
    this.request('GET', ['supplier', supplier_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};

Supplier.prototype.update = function(supplier_id, params, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!supplier_id) {
        return callback(new Error('Symphony Error (supplier_id parameter required)'));
    }
    this.request('PUT', ['supplier', supplier_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {
        name: params.name,
        address: params.address,
        contact_person: params.contact_person,
        contact_number: params.contact_number
    }, callback, function(res, result) {
        callback(null, result);
    });
};

Supplier.prototype.delete = function(supplier_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!supplier_id) {
        return callback(new Error('Symphony Error (supplier_id parameter required)'));
    }
    this.request('DELETE', ['supplier', supplier_id], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};


Supplier.prototype.view_tags = function(supplier_id, callback) {
    if (!this.options.userAuthKey) {
        return callback(new Error('Symphony Error (userAuthKey parameter required)'));
    } else if (!this.options.accessCode) {
        return callback(new Error('Symphony Error (accessCode parameter required)'));
    } else if (!this.options.accessKey) {
        return callback(new Error('Symphony Error (accessKey parameter required)'));
    }

    if (!supplier_id) {
        return callback(new Error('Symphony Error (supplier_id parameter required)'));
    }
    this.request('GET', ['supplier', supplier_id, 'tags'], this.options.accessCode, this.options.accessKey, this.options.userAuthKey, {}, callback, function(res, result) {
        callback(null, result);
    });
};
